
var webui_i18n = {
    "BAD REQUEST": "MAUVAISE DEMANDE",
    "UNAUTHORIZED": "NON AUTORISÉ",
    "FORBIDDEN": "INTERDIT",
    "NOT FOUND": "PAS TROUVÉ",
    "METHOD NOT ALLOWED": "MÉTHODE NON AUTORISÉE",
    "TOO MANY REQUESTS": "TROP DE DEMANDES",
    "INTERNAL SERVER ERROR": "ERREUR INTERNE DU SERVEUR",
    "NOT IMPLEMENTED": "PAS MIS EN ŒUVRE",
    "BAD GATEWAY": "MAUVAISE PASSERELLE",
    "SERVICE UNAVAILABLE": "SERVICE INDISPONIBLE",
    "GATEWAY TIMEOUT": "TEMPS DE PORTE",

    "request cancelled": "demande annulée",
    "no connection": "pas de connection",
    "request failed": "demande échoué",
    "Failed to load all page contents !!": "Impossible de charger tout le contenu de la page !!",
    "Please reload page and try again.": "Veuillez recharger la page et réessayer.",
};
